@media all {
    * {
        background-color: rgb(0 0 0) !important;
        background-image: none !important;
        border-color: rgb(78 154 6 / 60%) !important;
        color: rgb(78 154 6) !important;
        font-family: monospace;
    }

    body {
        font-size: 1.4rem;
    }

    .nav-pills > li > a.active,
    .nav-pills > li > a:hover {
        background-color: rgb(78 154 6 / 40%) !important;
        color: rgb(0 0 0) !important;
    }

    .nav-pills > li > a.active i,
    .nav-pills > li > a:hover i {
        background-color: transparent !important;
        color: rgb(0 0 0) !important;
    }

    .template-dark-mode .nav-tabs > li.active > a {
        background-color: rgb(78 154 6 / 40%) !important;
        color: rgb(0 0 0) !important;
    }

    .badge {
        background-color: rgb(78 154 6 / 40%) !important;
        color: rgb(0 0 0) !important;
    }

    #wrapper .nav-tabs > li.active > a {
        background-color: rgb(78 154 6 / 40%) !important;
        color: rgb(0 0 0) !important;
    }

    /* in case someone puts the nav into a panel header ...
    ------------------------------------------------------- */
    .panel-heading .nav-pills > li > a:hover,
    .panel-heading .nav-pills > li.active > a,
    .panel-heading .nav-pills > li.active > a:focus,
    .panel-heading .nav-pills > li.active > a:hover {
        background-color: rgb(78 154 6 / 40%) !important;
        background-image: none;
        background-repeat: no-repeat;
        border: none;
        color: rgb(0 0 0) !important;
        filter: none;
    }
}

/* AA Fittings
------------------------------------------------------------------------------------- */
@media all {
    #Fitting_Panel,
    #Fitting_Panel * {
        background-color: transparent !important;
    }
}
